\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{hrtprop}[2009/11/20 v1.0 A Simple Form]

\LoadClass[11pt,a4paper]{article}

\RequirePackage{wasysym}
\RequirePackage[bottom=2.5cm, bottom=2.5cm, left=2cm, right=2cm]{geometry}
\RequirePackage{graphicx}
\RequirePackage{forloop}
\RequirePackage{longtable}
\RequirePackage{ifthen}

\pagestyle{empty}

\newcommand*{\@fillinfont}{}
\newcommand*{\@formfont}{}
\newcommand*{\@unchecked}{\Square}
\newcommand*{\@checked}{\XBox}

\newcommand*{\@AOinfo}{9}

\newcommand*{\@ptitle}{Proposal title}
\newcommand*{\ptitle}[1]{\renewcommand*{\@ptitle}{#1}}

\newcommand*{\@PI}{}
\newcommand*{\PI}[3]{\newcommand*{\@PIName}{#1}  \newcommand*{\@PIAff}{#2}  \newcommand*{\@PIMail}{#3}}

% Collect COI information
\newcommand*{\@coitable}{}
\newcommand*{\@COI}{}
\newcommand*{\COI}[2]
  {
    \expandafter\def\expandafter\@coitable\expandafter{\@coitable { }#1 & #2 \\}
  } 



% Define the time constraints
\def\TC@no{None}
\def\TC@loose{}
\def\TC@periodic{}
\def\TC@strict{}
\def\TC@tcSetByUser{no}

\newcommand*{\setTC}[1]
  {
    \@ifundefined{TC@#1}
      {
        \ClassError{hrtprop}{Unknown time constraint ``#1''}{}
      }
      {
        \def\TC@no{}
        \@namedef{TC@#1}{#1}
        \@namedef{TC@tcSetByUser}{yes}
      }
  }

% Handle proposal type
\newcommand*{\reset@propType}{
  \def\propType@normal{\@unchecked}
  \def\propType@survey{\@unchecked}
  \def\propType@monitoring{\@unchecked}
  \def\propType@TOO{\@unchecked}
}

\reset@propType

\newcommand*{\propType}[1]
  {
    \@ifundefined{propType@#1}
      {
        \ClassError{hrtprop}{Unknown proposal type ``#1''}{}
      }
      {
        \reset@propType
        \newcommand*{\@propTypeName}{#1}
      }
  }


\newcommand*{\@timeRequest}{Obs. time request & \textbf{0 h}}
\newcommand*{\totObsTime}[1]
  {
    \renewcommand*{\@timeRequest}{Obs. time request & \textbf{#1 h}}
  }

\newcommand*{\obsTimeRate}[1]
  {
    \renewcommand*{\@timeRequest}{Obs. time request & \textbf{#1 h/half-year}}
  }

\newcommand*{\@start}{ASAP}
\newcommand*{\start}[1]{\renewcommand*{\@start}{#1}}

\newcommand*{\@duration}{undefined}
\newcommand*{\duration}[1]{\renewcommand*{\@duration}{#1}}

\newcommand{\@abstract}{}
\renewcommand{\abstract}[1]{\renewcommand{\@abstract}{#1}}

\newcommand{\@SR}{}
\newcommand{\scientificRationale}[1]{\renewcommand{\@SR}{#1}}

\newcommand{\@outreach}{}
\newcommand{\outr}[1]{\renewcommand{\@outreach}{#1}}

\newcommand{\@feasibility}{}
\newcommand{\feasibility}[1]{\renewcommand{\@feasibility}{#1}}

\newcommand{\@isLongProgram}{}
 \newcommand{\isLongProgram}[0]{\renewcommand{\@isLongProgram}{, long}}

\newcommand{\@jointProposal}{}
\newcommand{\isJointProposal}[1]{\renewcommand{\@jointProposal}{#1}}

\newcounter{targetCounter}
\setcounter{targetCounter}{0}

\newcommand{\addTarget}[4]
  {
    \addtocounter{targetCounter}{1}
    \@namedef{@tName@\thetargetCounter}{#1}
    \@namedef{@tRa@\thetargetCounter}{#2}
    \@namedef{@tDec@\thetargetCounter}{#3}
    \@namedef{@tmv@\thetargetCounter}{#4}
  }

\newlength\boxwidth
\newlength\underlinewidth

\newcommand{\makeform}{%
  % Set default time constraints. User input overrules
  % default time constraints
  \ifthenelse{\equal{\TC@tcSetByUser}{no}}
  {
    \ifthenelse{\equal{\@propTypeName}{monitoring}}{\setTC{loose}}{}
    }{}
  \@formfont
  \begin{center}\large\bfseries
  {\huge El TIGRE observing proposal}
  \end{center}
  
  {\begin{center} \large \textbf{AO: \@AOinfo} \end{center}}
  
  {\noindent
  \textbf{\underline{PI information:}\\[2mm]}
  \begin{tabular}[h]{l l}
  Name & \@PIName \\
  Affiliation & \@PIAff \\
  E-mail & \@PIMail \\
  \end{tabular}
  } \\[0.5cm]
  
  {\noindent
  \textbf{\underline{COI information:}\\[2mm]}
  \begin{tabular}[h]{l l}
  Name & Affiliation \\ \hline
  \@coitable \hline
  \end{tabular}
  } \\[0.5cm]
  
  \noindent
  \textbf{\underline{Proposal information:}\\[2mm]}
  \fbox{
  \begin{tabular}{l l}
  Proposal type & \textit{normal, survey, monitoring, TOO, [long]} \\
                & \textbf{\@propTypeName \@isLongProgram} \\
  Joint proposal & \textbf{\@jointProposal} \\
  Time constraints & \textit{none, loose, strict, periodic} \\
                   & \textbf{\TC@no  \TC@loose  \TC@strict  \TC@periodic} \\
%   Proposed start & \textbf{\@start} \\
  Duration & \textbf{\@duration} \\
  \@timeRequest \\
  \end{tabular}
  }
  
  \vspace{1cm}
  
  \noindent
  \rule{1\textwidth}{0.4pt}\\[-3mm]
  \rule{1\textwidth}{0.4pt}
  
%   \vspace{1cm}

  {\begin{center} \textbf{\Large \@ptitle} \end{center}}
  
  \noindent
  \large \textbf{Abstract}: {\small (7~lines $\approx 100$ words)} \\ 

   
   \noindent
   \begin{minipage}[c][0.142\textheight][l]{\textwidth}
     \@abstract
   \end{minipage}

   \noindent
   \rule{1\textwidth}{0.4pt}
  
   \noindent
   \large \textbf{Non-technical abstract}: {\small (3~lines $\approx 50$ words)}\\
  
  
   \noindent
   \begin{minipage}[c][0.082\textheight][l]{\textwidth}
     \@outreach
   \end{minipage}

   \noindent
   \rule{1\textwidth}{0.4pt}
  
  \newpage
  
  \noindent
  {\Large \textbf{Scientific rationale:} {\small (1~page)} \\[2mm]}
  {\@SR}
  
  \newpage
  \noindent
  {\Large \textbf{Feasibility:}\\[2mm]}
  \begin{minipage}[c][0.33\textheight][l]{\textwidth}
    \@feasibility
  \end{minipage}

  \noindent
  \rule{1\textwidth}{0.4pt}  
  \vspace{0.5cm}
  
  \noindent
  {\Large \textbf{Object information}:}\\[-2mm]
  
  \noindent
  {\large (Observation and scheduling details are submitted via
  the online form.)}
  
  \noindent
  \begin{longtable}[h]{l l l l l} \hline \hline
  Number & Object & Ra & Dec & m$_V$ \\ \hline
  \newcounter{ct}%
  \newcounter{loopLimit}%
  \setcounter{loopLimit}{\value{targetCounter}}%
  \addtocounter{loopLimit}{1}%
  \forloop{ct}{1}{\value{ct} < \value{loopLimit}}%
  {%
    $\thect$ & \@nameuse{@tName@\thect} & $\@nameuse{@tRa@\thect}$ & \
    $\@nameuse{@tDec@\thect}$ & \@nameuse{@tmv@\thect} \\
  }
  \\[-5mm] \hline
  \end{longtable}

}
\endinput
